'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var jsxRuntime = require('react/jsx-runtime');
var classNames = _interopDefault(require('classnames'));
var react = require('react');
var Button$1 = require('reakit/Button');
var Checkbox$1 = require('reakit/Checkbox');
var Menu = require('reakit/Menu');
var Input$1 = require('reakit/Input');
var Separator$1 = require('reakit/Separator');
var Composite = require('reakit/Composite');
var Dialog = require('reakit/Dialog');
var Role = require('reakit/Role');
var Tab = require('reakit/Tab');

function Avatar(_ref) {
  var username = _ref.username,
      src = _ref.src,
      className = _ref.className;
  return jsxRuntime.jsx("img", {
    alt: username + "'s Avatar",
    className: classNames('object-cover object-center w-10 h-10 rounded-full group-focus:ring-2 ring-primary-500', className),
    src: src
  }, void 0);
}
Avatar.defaultProps = {
  className: null
};

function Badge(_ref) {
  var variant = _ref.variant,
      className = _ref.className,
      children = _ref.children,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'small' : _ref$size;
  return jsxRuntime.jsx("span", Object.assign({
    className: classNames('py-1 rounded-lg font-medium tracking-wider uppercase', {
      'bg-success-50 text-success-700': variant === 'success',
      'bg-danger-50 text-danger-700': variant === 'danger',
      'bg-warning-50 text-warning-700': variant === 'warning',
      'bg-info-50 text-info-700': variant === 'info',
      'px-2 text-xs': size === 'small',
      'px-3': size === 'large'
    }, className)
  }, {
    children: children
  }), void 0);
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

// --------------------
// UTILS
// --------------------

function forwardRefWithAs(component) {
  return react.forwardRef(component);
}

var buttonClasses = function buttonClasses(variant, size, primary, danger, rounded) {
  var contained = variant === 'contained';
  var outlined = variant === 'outlined';
  var text = variant === 'text';
  var primaryOrDanger = primary || danger;
  var outlineOrText = outlined || text;
  return classNames('focus:outline-none focus:ring-2 transition disabled:bg-opacity-75 disabled:cursor-default font-medium', {
    'ring-danger-500': danger,
    'ring-primary-500': !danger,
    'text-white': contained && primaryOrDanger,
    'bg-primary-500 hover:bg-primary-600': contained && primary,
    'bg-danger-500 hover:bg-danger-600': contained && danger,
    'bg-white border border-gray-soft disabled:bg-gray-cool-50': contained && !primaryOrDanger,
    border: outlined,
    'border-primary-500 hover:bg-primary-500': outlined && primary,
    'text-primary-500': outlineOrText && primary,
    'border-danger-500 hover:bg-danger-500': outlined && danger,
    'text-danger-500': outlineOrText && danger,
    'border-gray-soft hover:bg-gray-cool-50': outlined && !primaryOrDanger,
    'hover:bg-gray-cool-50': contained && !primaryOrDanger || text,
    'text-gray': !primaryOrDanger,
    'ring-offset-2': (contained || outlined) && primaryOrDanger,
    'h-8': size === 'small',
    'h-10': size === 'medium',
    'h-12': size === 'large',
    'rounded-full': rounded,
    'rounded-lg': !rounded
  });
};

function ButtonComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'button' : _ref$as,
      children = _ref.children,
      className = _ref.className,
      rounded = _ref.rounded,
      _ref$primary = _ref.primary,
      primary = _ref$primary === void 0 ? false : _ref$primary,
      _ref$danger = _ref.danger,
      danger = _ref$danger === void 0 ? false : _ref$danger,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'contained' : _ref$variant,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      startIcon = _ref.startIcon,
      endIcon = _ref.endIcon,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "children", "className", "rounded", "primary", "danger", "variant", "size", "startIcon", "endIcon"]);

  var prefixIcon = startIcon ? react.cloneElement(startIcon, {
    className: 'w-5 h-5 mr-3'
  }) : null;
  var suffixIcon = endIcon ? react.cloneElement(endIcon, {
    className: 'w-5 h-5 ml-3'
  }) : null;
  var small = size === 'small';
  var medium = size === 'medium';
  var large = size === 'large';
  return jsxRuntime.jsxs(Button$1.Button, Object.assign({
    as: Type,
    className: classNames('flex items-center', {
      'pl-3': small && startIcon,
      'pl-4': medium && startIcon || small && !startIcon,
      'pl-5': large && startIcon || medium && !startIcon,
      'pl-6': large && !startIcon,
      'pr-3': small && endIcon,
      'pr-4': medium && endIcon || small && !endIcon,
      'pr-5': large && endIcon || medium && !endIcon,
      'pr-6': large && !endIcon
    }, buttonClasses(variant, size, primary, danger, rounded), className)
  }, props, {
    ref: ref
  }, {
    children: [prefixIcon, children, suffixIcon]
  }), void 0);
}

var Button = /*#__PURE__*/forwardRefWithAs(ButtonComponent);

function IconButtonComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'button' : _ref$as,
      children = _ref.children,
      className = _ref.className,
      _ref$rounded = _ref.rounded,
      rounded = _ref$rounded === void 0 ? true : _ref$rounded,
      _ref$primary = _ref.primary,
      primary = _ref$primary === void 0 ? false : _ref$primary,
      _ref$danger = _ref.danger,
      danger = _ref$danger === void 0 ? false : _ref$danger,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'text' : _ref$variant,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "children", "className", "rounded", "primary", "danger", "variant", "size"]);

  var icon = react.cloneElement(children, {
    className: 'w-5 h-5'
  });
  return jsxRuntime.jsx(Button$1.Button, Object.assign({
    as: Type,
    className: classNames('flex items-center justify-center', {
      'w-8': size === 'small',
      'w-10': size === 'medium',
      'w-12': size === 'large'
    }, buttonClasses(variant, size, primary, danger, rounded), className)
  }, props, {
    ref: ref
  }, {
    children: icon
  }), void 0);
}

var IconButton = /*#__PURE__*/forwardRefWithAs(IconButtonComponent);

function CardLink(_ref) {
  var children = _ref.children,
      href = _ref.href,
      className = _ref.className;
  return jsxRuntime.jsx("a", Object.assign({
    className: classNames('text-gray tracking-wider uppercase', className),
    href: href
  }, {
    children: children
  }), void 0);
}
CardLink.defaultProps = {
  children: null,
  href: '#',
  className: null
};

function CardTitle(_ref) {
  var children = _ref.children,
      className = _ref.className;
  return jsxRuntime.jsx("h2", Object.assign({
    className: classNames('text-lg font-medium text-gray-dark', className)
  }, {
    children: children
  }), void 0);
}
CardTitle.defaultProps = {
  children: null,
  className: null
};

function Card(_ref) {
  var children = _ref.children,
      className = _ref.className;
  return jsxRuntime.jsx("div", Object.assign({
    className: classNames('rounded-lg bg-white shadow-big', className)
  }, {
    children: children
  }), void 0);
}
Card.Title = CardTitle;
Card.Link = CardLink;
Card.defaultProps = {
  children: null,
  className: null
};

function CheckboxComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'input' : _ref$as,
      checked = _ref.checked,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "checked", "className"]);

  return jsxRuntime.jsx(Checkbox$1.Checkbox, Object.assign({
    as: Type,
    checked: checked,
    className: classNames('checkbox w-4 h-4 rounded border-gray-soft appearance-none border focus:outline-none focus:ring-2 ring-offset-2 ring-primary-500 checked:border-primary-500 checked:bg-primary-500', className)
  }, props, {
    ref: ref
  }), void 0);
}

var Checkbox = /*#__PURE__*/forwardRefWithAs(CheckboxComponent);

var DropdownContext = /*#__PURE__*/react.createContext(null);

function DropdownButton(_ref) {
  var children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["children"]);

  var state = react.useContext(DropdownContext);
  return jsxRuntime.jsx(Menu.MenuButton, Object.assign({
    className: "group focus:outline-none"
  }, state, props, {
    children: children
  }), void 0);
}

function DropdownItemComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'button' : _ref$as,
      children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "children", "className"]);

  var state = react.useContext(DropdownContext);
  return jsxRuntime.jsx(Menu.MenuItem, Object.assign({
    as: Type,
    className: classNames('block w-full text-left px-4 py-2 focus:outline-none text-gray-dark focus:bg-gray-soft focus:bg-opacity-25', className)
  }, state, props, {
    ref: ref
  }, {
    children: children
  }), void 0);
}

var DropdownItem = /*#__PURE__*/forwardRefWithAs(DropdownItemComponent);

function DropdownList(_ref) {
  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  var state = react.useContext(DropdownContext);
  return jsxRuntime.jsx(Menu.Menu, Object.assign({
    className: classNames('transition-opacity w-48 py-1 rounded-lg shadow-soft bg-white focus:outline-none z-20 data-enter:opacity-100 opacity-0', className)
  }, state, props, {
    children: children
  }), void 0);
}

function DropdownSeparator(_ref) {
  var props = _extends({}, _ref);

  var state = react.useContext(DropdownContext);
  return jsxRuntime.jsx(Menu.MenuSeparator, Object.assign({}, state, props), void 0);
}

function Dropdown(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? {} : _ref$options;
  var state = Menu.useMenuState(_extends({
    animated: true,
    placement: 'bottom-end',
    gutter: 8
  }, options));
  return jsxRuntime.jsx("div", Object.assign({
    className: className
  }, {
    children: jsxRuntime.jsx(DropdownContext.Provider, Object.assign({
      value: state
    }, {
      children: children
    }), void 0)
  }), void 0);
}
Dropdown.defaultProps = {
  children: null,
  className: null,
  options: {}
};
Dropdown.Button = DropdownButton;
Dropdown.Item = DropdownItem;
Dropdown.List = DropdownList;
Dropdown.Separator = DropdownSeparator;

var inputClasses = function inputClasses(disabled, isInvalid, isValid, border, focusWithin) {
  return classNames('px-4 focus:outline-none', {
    'bg-gray-cool-100': disabled,
    'border-gray-soft ring-primary-500': !isInvalid && !isValid && border,
    'border-transparent ring-danger-500 ring-2': isInvalid && border,
    'border-transparent ring-success-500 ring-2': isValid && border,
    'rounded-lg border transition': border,
    'focus:border-transparent focus:ring-2': !focusWithin && border,
    'focus-within:border-transparent focus-within:ring-2': focusWithin && border
  });
};

var Input = /*#__PURE__*/react.forwardRef(function (_ref, ref) {
  var className = _ref.className,
      disabled = _ref.disabled,
      _ref$isInvalid = _ref.isInvalid,
      isInvalid = _ref$isInvalid === void 0 ? false : _ref$isInvalid,
      _ref$isValid = _ref.isValid,
      isValid = _ref$isValid === void 0 ? false : _ref$isValid,
      _ref$border = _ref.border,
      border = _ref$border === void 0 ? true : _ref$border,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "disabled", "isInvalid", "isValid", "border"]);

  return jsxRuntime.jsx(Input$1.Input, Object.assign({
    className: classNames('h-10', inputClasses(disabled, isInvalid, isValid, border), className),
    disabled: disabled,
    ref: ref
  }, props), void 0);
});

var TextareaInput = /*#__PURE__*/react.forwardRef(function (_ref, ref) {
  var className = _ref.className,
      _ref$resize = _ref.resize,
      resize = _ref$resize === void 0 ? 'none' : _ref$resize,
      disabled = _ref.disabled,
      isInvalid = _ref.isInvalid,
      isValid = _ref.isValid,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "resize", "disabled", "isInvalid", "isValid"]);

  return jsxRuntime.jsx("textarea", Object.assign({
    className: classNames('py-2', {
      'resize-none': resize === 'none',
      resize: resize === 'both',
      'resize-y': resize === 'vertical',
      'resize-x': resize === 'horizontal'
    }, inputClasses(disabled, isInvalid, isValid, true), className),
    disabled: disabled,
    ref: ref
  }, props), void 0);
});

function Label(_ref) {
  var className = _ref.className,
      children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "children"]);

  return jsxRuntime.jsx("label", Object.assign({
    className: classNames('text-gray-dark', className)
  }, props, {
    children: children
  }), void 0);
}

var MediaContext = /*#__PURE__*/react.createContext({
  size: 'medium'
});

function MediaBody(_ref) {
  var children = _ref.children,
      className = _ref.className;

  var _useContext = react.useContext(MediaContext),
      size = _useContext.size;

  return jsxRuntime.jsx("div", Object.assign({
    className: classNames('flex-1', {
      'ml-4': size === 'medium',
      'ml-6': size === 'large'
    }, className)
  }, {
    children: children
  }), void 0);
}
MediaBody.defaultProps = {
  children: null,
  className: null
};

function MediaDesc(_ref) {
  var children = _ref.children,
      className = _ref.className;

  var _useContext = react.useContext(MediaContext),
      size = _useContext.size;

  return jsxRuntime.jsx("div", Object.assign({
    className: classNames({
      'mt-2': size === 'medium',
      'mt-3': size === 'large'
    }, className)
  }, {
    children: children
  }), void 0);
}
MediaDesc.defaultProps = {
  children: null,
  className: null
};

function MediaNumber(_ref) {
  var children = _ref.children;
  return jsxRuntime.jsx("span", Object.assign({
    className: "text-2xl w-14 text-primary-800"
  }, {
    children: children
  }), void 0);
}
MediaNumber.defaultProps = {
  children: null
};

function MediaThumbnail(_ref) {
  var src = _ref.src,
      alt = _ref.alt,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className;

  var _useContext = react.useContext(MediaContext),
      size = _useContext.size;

  return jsxRuntime.jsx("img", {
    alt: alt,
    className: classNames('object-cover rounded-lg', {
      'w-16 h-16': size === 'medium',
      'w-20 h-20': size === 'large'
    }, className),
    src: src
  }, void 0);
}
MediaThumbnail.defaultProps = {
  className: null
};

function MediaTitle(_ref) {
  var children = _ref.children,
      className = _ref.className;

  var _useContext = react.useContext(MediaContext),
      size = _useContext.size;

  return jsxRuntime.jsx("h3", Object.assign({
    className: classNames('text-gray-dark text-left', {
      'text-base': size === 'large'
    }, className)
  }, {
    children: children
  }), void 0);
}
MediaTitle.defaultProps = {
  children: null,
  className: null
};

function Media(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size;
  return jsxRuntime.jsx("div", Object.assign({
    className: classNames('flex items-center', className)
  }, {
    children: jsxRuntime.jsx(MediaContext.Provider, Object.assign({
      value: {
        size: size
      }
    }, {
      children: children
    }), void 0)
  }), void 0);
}
Media.defaultProps = {
  children: null,
  className: null,
  size: 'medium'
};
Media.Body = MediaBody;
Media.Desc = MediaDesc;
Media.Number = MediaNumber;
Media.Title = MediaTitle;
Media.Thumbnail = MediaThumbnail;

function PageTitle(_ref) {
  var text = _ref.text,
      className = _ref.className;
  return jsxRuntime.jsx("h1", Object.assign({
    className: classNames('text-4xl tracking-wide font-medium text-gray-dark', className)
  }, {
    children: text
  }), void 0);
}
PageTitle.defaultProps = {
  className: null
};

function Separator(_ref) {
  var className = _ref.className,
      _ref$orientation = _ref.orientation,
      orientation = _ref$orientation === void 0 ? 'horizontal' : _ref$orientation,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "orientation"]);

  return jsxRuntime.jsx(Separator$1.Separator, Object.assign({
    className: classNames('border-t border-gray-soft', className),
    orientation: orientation
  }, props), void 0);
}

var SidenavCompositeContext = /*#__PURE__*/react.createContext(null);

function SidenavItemComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'a' : _ref$as,
      children = _ref.children,
      icon = _ref.icon,
      active = _ref.active,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "children", "className", "icon", "active"]);

  var iconEl = null;
  var state = react.useContext(SidenavCompositeContext);

  if (icon) {
    iconEl = react.cloneElement(icon, {
      className: 'w-5 h-5 mr-5'
    });
  }

  return jsxRuntime.jsx("li", {
    children: jsxRuntime.jsxs(Composite.CompositeItem, Object.assign({
      as: Type,
      className: classNames('w-full h-14 px-4 rounded-lg tracking-wider flex items-center transition focus:outline-none focus:ring-2 ring-primary-500', {
        'bg-white bg-opacity-10 text-white font-medium': active,
        'text-primary-50 hover:bg-white hover:bg-opacity-5': !active
      })
    }, props, state, {
      ref: ref
    }, {
      children: [iconEl, children]
    }), void 0)
  }, void 0);
}

var SidenavItem = /*#__PURE__*/forwardRefWithAs(SidenavItemComponent);

function SidenavList(_ref) {
  var title = _ref.title,
      children = _ref.children,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className;
  return jsxRuntime.jsxs("div", Object.assign({
    className: classNames('last:pb-8', {
      'pt-6': !className.includes('pt-')
    }, className)
  }, {
    children: [title && jsxRuntime.jsx("h3", Object.assign({
      className: classNames('px-10 text-xs tracking-widest uppercase text-white text-opacity-80')
    }, {
      children: title
    }), void 0), jsxRuntime.jsx(Role.Role, Object.assign({
      as: "ul",
      className: "px-4 mt-4 space-y-4"
    }, {
      children: children
    }), void 0)]
  }), void 0);
}

function SidenavTitle(_ref) {
  var children = _ref.children,
      href = _ref.href;
  return jsxRuntime.jsx("a", Object.assign({
    className: "flex items-center justify-center h-20 text-lg font-medium tracking-wider text-white focus:outline-none",
    href: href
  }, {
    children: children
  }), void 0);
}
SidenavTitle.defaultProps = {
  href: '#'
};

function Sidenav(_ref) {
  var _ref$open = _ref.open,
      open = _ref$open === void 0 ? true : _ref$open,
      handleClose = _ref.handleClose,
      children = _ref.children,
      className = _ref.className;
  var dialog = Dialog.useDialogState({
    animated: true,
    visible: open,
    modal: false
  });
  var composite = Composite.useCompositeState({
    orientation: 'vertical'
  });
  react.useEffect(function () {
    dialog.setVisible(open);
  }, [dialog, open]);
  return jsxRuntime.jsxs(jsxRuntime.Fragment, {
    children: [jsxRuntime.jsx(Dialog.Dialog, Object.assign({}, dialog, {
      "aria-label": "Sidebar",
      as: "aside",
      className: classNames('group fixed top-0 lg:sticky bg-primary-900 transition-margin duration-300 h-full min-h-screen w-72 flex-shrink-0 -ml-72 data-enter:ml-0 shadow-md z-50 focus:outline-none', className),
      hideOnEsc: function () {
        return window.innerWidth <= 768;
      }(),
      style: {
        willChange: 'margin'
      }
    }, {
      children: jsxRuntime.jsx("nav", {
        children: jsxRuntime.jsx(SidenavCompositeContext.Provider, Object.assign({
          value: composite
        }, {
          children: jsxRuntime.jsx(Composite.Composite, Object.assign({}, composite, {
            "aria-label": "Sidenav menu",
            role: "menu"
          }, {
            children: children
          }), void 0)
        }), void 0)
      }, void 0)
    }), void 0), jsxRuntime.jsx(Dialog.DialogBackdrop, Object.assign({}, dialog, {
      className: "fixed w-full h-full duration-300 bg-black bg-opacity-0 lg:w-0 transition-background-opacity data-enter:bg-opacity-60",
      onClick: function onClick() {
        return handleClose == null ? void 0 : handleClose();
      }
    }), void 0)]
  }, void 0);
}
Sidenav.defaultProps = {
  open: true,
  handleClose: null,
  children: null,
  className: null
};
Sidenav.Item = SidenavItem;
Sidenav.List = SidenavList;
Sidenav.Title = SidenavTitle;

function StatsDesc(_ref) {
  var text = _ref.text,
      icon = _ref.icon,
      className = _ref.className;
  var iconEl = icon ? react.cloneElement(icon, {
    className: classNames('w-4 h-4 mr-2', className)
  }) : null;
  return jsxRuntime.jsxs("span", Object.assign({
    className: classNames('flex items-center text-gray', className)
  }, {
    children: [iconEl, text]
  }), void 0);
}
StatsDesc.defaultProps = {
  text: null,
  icon: null,
  className: null
};

var TabsContext = /*#__PURE__*/react.createContext(null);

function TabsButton(_ref) {
  var _button$current, _button$current2;

  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  var state = react.useContext(TabsContext);
  var button = react.useRef(null);
  var active = ((_button$current = button.current) == null ? void 0 : _button$current.id) && ((_button$current2 = button.current) == null ? void 0 : _button$current2.id) === (state == null ? void 0 : state.selectedId);
  return jsxRuntime.jsxs(Tab.Tab, Object.assign({
    className: classNames('focus:outline-none group', {
      'font-medium text-gray-dark': active,
      'text-gray': !active
    }, className)
  }, state, props, {
    ref: button
  }, {
    children: [jsxRuntime.jsx("div", Object.assign({
      className: "tracking-wider rounded-lg group-focus:ring-2 ring-primary-500 ring-offset-2"
    }, {
      children: children
    }), void 0), jsxRuntime.jsx("div", {
      className: classNames('w-full h-1 mt-3.5', {
        'bg-primary-500': active
      })
    }, void 0)]
  }), void 0);
}

function TabsList(_ref) {
  var className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["className"]);

  var state = react.useContext(TabsContext);
  return jsxRuntime.jsx(Tab.TabList, Object.assign({
    className: classNames('flex space-x-10', className)
  }, state, props), void 0);
}

function TabsPanel(_ref) {
  var className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["className"]);

  var state = react.useContext(TabsContext);
  return jsxRuntime.jsx(Tab.TabPanel, Object.assign({
    className: classNames('focus:outline-none', className)
  }, state, props), void 0);
}

function Tabs(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? {} : _ref$options;
  var state = Tab.useTabState(options);
  return jsxRuntime.jsx("div", Object.assign({
    className: className
  }, {
    children: jsxRuntime.jsx(TabsContext.Provider, Object.assign({
      value: state
    }, {
      children: children
    }), void 0)
  }), void 0);
}
Tabs.defaultProps = {
  children: null,
  className: null,
  options: {}
};
Tabs.Button = TabsButton;
Tabs.List = TabsList;
Tabs.Panel = TabsPanel;

exports.Avatar = Avatar;
exports.Badge = Badge;
exports.Button = Button;
exports.Card = Card;
exports.Checkbox = Checkbox;
exports.Dropdown = Dropdown;
exports.IconButton = IconButton;
exports.Input = Input;
exports.Label = Label;
exports.Media = Media;
exports.PageTitle = PageTitle;
exports.Separator = Separator;
exports.Sidenav = Sidenav;
exports.StatsDesc = StatsDesc;
exports.Tabs = Tabs;
exports.TextareaInput = TextareaInput;
//# sourceMappingURL=react.cjs.development.js.map
