import { ReactNode } from 'react';

import { DialogInitialState, useDialogState } from 'reakit/Dialog';

import { ModalButton } from './button';
import { ModalContext } from './context';
import { ModalDialog } from './dialog';

interface ModalProps {
  children?: ReactNode;
  className?: string;
  options?: DialogInitialState;
}

export function Modal({ children, className, options = {} }: ModalProps) {
  const state = useDialogState({ animated: true, ...options });
  return (
    <div className={className}>
      <ModalContext.Provider value={state}>{children}</ModalContext.Provider>
    </div>
  );
}

Modal.defaultProps = {
  children: null,
  className: null,
  options: {},
};

Modal.Button = ModalButton;
Modal.Dialog = ModalDialog;
